@@ -4,8 +4,12 @@
 #
 #   portions taken from the Jokosher project
 #
-
-import ConfigParser
+try:
+    #python2.x
+    import ConfigParser as configparser
+except:
+    #python3
+    import configparser
 import os
 import re
 
@@ -74,6 +78,10 @@ class ConfigTokenizer():
         return self
 
     def next(self):
+        """for python2"""
+        return self.__next__()
+
+    def __next__(self):
         for r in self._parse_order:
             m = r.match(self._consumable)
             if m:
@@ -104,19 +112,22 @@ class Settings:
 
         Parameters:
             filename -- path to the settings file.
-                        If None, the default ~/.dfeet/config will be used.
+                        If None, the default $XDG_CONFIG_HOME/d-feet/config will be used.
         """
         if not filename:
-            self.filename = os.path.expanduser("~/.d-feet/config")
+            if 'XDG_CONFIG_HOME' in list(os.environ.keys()):
+                self.filename = os.path.join(os.environ['XDG_CONFIG_HOME'], 'd-feet', 'config')
+            else:
+                self.filename = os.path.join(os.environ['HOME'], '.config', 'd-feet', 'config')
         else:
             self.filename = filename
-        self.config = ConfigParser.ConfigParser()
+        self.config = configparser.ConfigParser()
 
         self.read()
 
     @classmethod
     def get_instance(cls):
-        """ This class is a singlton so use this method to get it """
+        """This class is a singlton so use this method to get it"""
         if cls.instance:
             return cls.instance
 
@@ -125,7 +136,7 @@ class Settings:
 
     def decode_list(self, s):
         result = []
-        lex = ConfigTokenizer(s);
+        lex = ConfigTokenizer(s)
         for item in lex:
             if item.is_value():
                 result.append(str(item))
@@ -166,12 +177,12 @@ class Settings:
             if self.general[key] == None:
                 self.general[key] = ''
 
-            self.config.set("General", key, self.general[key])
+            self.config.set("General", str(key), str(self.general[key]))
 
         # make sure that the directory that the config file is in exists
         new_file_dir = os.path.split(self.filename)[0]
         if not os.path.isdir(new_file_dir):
             os.makedirs(new_file_dir)
-        file = open(self.filename, 'w')
-        self.config.write(file)
-        file.close()
+        f = open(self.filename, 'w')
+        self.config.write(f)
+        f.close()
